package biggests.clustering;

import java.util.Comparator;

/**
 * <p>Title: Hierarchical Cluster Tree Node Comparator</p>
 *
 * <p>Description: Implements Comparator interface. Allows comparison
 *                 operations between two cluster tree nodes.</p>
 *
 * <p>Copyright:   Copyright (C) 2007  Joana Gonçalves
 *                 This program is free software; you can redistribute
 *                 it and/or modify it under the terms of the GNU General
 *                 Public License as published by the Free Software
 *                 Foundation; either version 2 of the License, or
 *                 any later version.
 *
 *                 This program is distributed in the hope that it will
 *                 be useful, but WITHOUT ANY WARRANTY; without even the
 *                 implied warranty of MERCHANTABILITY or FITNESS FOR A
 *                 PARTICULAR PURPOSE.  See the
 *                 <a href="http://www.gnu.org/licenses/gpl.html">
 *                 GNU General Public License</a> for more details.
 * </p>
 *
 * @author Joana P. Gonçalves
 */
public class ClusterTreeNodeComparator implements Comparator {
    /**
     * Creates a new cluster tree node comparator.
     */
    public ClusterTreeNodeComparator() {
    }

    /**
     * Compares two <code>ClusterTreeNode</code>s, <code>o1</code>
     * and <code>o2</code>. Implements <code>Comparator</code>'s
     * <code>compare</code> method. Returns a negative integer, 0 or
     * positive integer if <code>o1</code> is less than, equal to,
     * or greater than <code>o2</code>.
     *
     * @param o1 <code>Object</code> the first <code>ClusterTreeNode</code>
     *        to compare
     * @param o2 <code>Object</code> the second <code>ClusterTreeNode</code>
     *        to compare
     * @return int the result of comparation (negative integer, 0 or postive
     *        integer if <code>o1</code> is less than, equal to,
     *        or greater than <code>o2</code>
     */
    public int compare(Object o1, Object o2) {
        Double distance1 = ((ClusterTreeNode) o1).getDistance();
        Double distance2 = ((ClusterTreeNode) o2).getDistance();
        return (distance1.compareTo(distance2));
    }

    /**
     * Indicates whether some other object is "equal to" this Comparator.
     *
     * @param obj the <code>Object</code> to compare with this Comparator
     * @return boolean <code>true</code> if obj is equal to this Comparator,
     *         <code>false</code> otherwise
     */
    public boolean equals(Object obj) {
        return (this.equals(obj));
    }
}
